@@ -2,7 +2,7 @@
 pycraigslist.models.filters
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-This module parses and gets additional Craigslist query filters.
+Handles parsing of Craigslist query filters.
 """
 
 from . import sessions
@@ -10,42 +10,42 @@ from . import sessions
 
 def get_addl_readable(url):
     """Gets additional Craigslist query filters in readable format."""
-    filters = get_addl(url)
-    for key, value in filters.copy().items():
+    addl_filters = get_addl(url)
+    for key, value in addl_filters.copy().items():
         if isinstance(value, dict):
             # Get only filter names
             # E.g. ['apartment', 'condo'] from {'apartment': '1', 'condo': '2'}
-            filters[key] = list(value)
+            addl_filters[key] = list(value)
 
-    return filters
+    return addl_filters
 
 
 def get_addl(url):
     """Gets additional Craigslist query filters."""
     # Additional filters constitute niche filters for a category
     # E.g. 'rent_period' is an additional filter for apartments / housing for rent
-    filters = {}
+    addl_filters = {}
     search_html = next(sessions.yield_html(url))
 
     for filter_item in search_html.find_all("div", class_="search-attribute"):
         filter_key = filter_item.attrs["data-attr"]
         filter_labels = filter_item.find_all("label")
-        filters[filter_key] = {
+        addl_filters[filter_key] = {
             opt.text.strip(): opt.find("input").get("value") for opt in filter_labels
         }
 
-    return filters
+    return addl_filters
 
 
-def parse(filters, search_filters, **kwargs):
-    """Parses and validates url and filters using categorical search filters as
+def parse(filters, query_filters, **kwargs):
+    """Parses and validates url and filters using categorical query filters as
     template reference. Returns filters for requests.get params."""
     filters = parse_arg_filters(filters, **kwargs)
     # Iterate over a copy of filters
     for key, value in filters.copy().items():
         try:
             # Substitute and remove key for url_key
-            url_key = search_filters[key]["url_key"]
+            url_key = query_filters[key]["url_key"]
             filters[url_key] = parse_value(value)
             if url_key != key:
                 # Delete old key
@@ -53,9 +53,7 @@ def parse(filters, search_filters, **kwargs):
         except KeyError:
             # Some filters allow multiple values - assign all specified by user
             try:
-                filters[key] = [
-                    search_filters[key][parsed_val] for parsed_val in parse_value(value)
-                ]
+                filters[key] = [query_filters[key][parsed_val] for parsed_val in parse_value(value)]
             except (KeyError, TypeError):
                 raise ValueError("filter '%s' is or has a bad value" % key)
 
@@ -75,7 +73,7 @@ def parse_arg_filters(filters, **kwargs):
 
 
 def parse_value(filter_value):
-    """Validates and further parses search filter values."""
+    """Validates and further parses query filter values."""
     # Returns filter value(s) as list
     if isinstance(filter_value, (float, str)):
         return [filter_value]
